@@ -1,25 +1,27 @@
+require 'digest/md5'
+
 module Listen
   class File
-    def self.change(record, dir, rel_path)
-      path = dir + rel_path
+    def self.change(record, rel_path)
+      path = Pathname.new(record.root) + rel_path
       lstat = path.lstat
 
       data = { mtime: lstat.mtime.to_f, mode: lstat.mode }
 
-      record_data = record.file_data(dir, rel_path)
+      record_data = record.file_data(rel_path)
 
       if record_data.empty?
-        record.async.update_file(dir, rel_path, data)
+        record.update_file(rel_path, data)
         return :added
       end
 
       if data[:mode] != record_data[:mode]
-        record.async.update_file(dir, rel_path, data)
+        record.update_file(rel_path, data)
         return :modified
       end
 
       if data[:mtime] != record_data[:mtime]
-        record.async.update_file(dir, rel_path, data)
+        record.update_file(rel_path, data)
         return :modified
       end
 
@@ -56,13 +58,13 @@ module Listen
       return if data[:mtime].to_i + 2 <= Time.now.to_f
 
       md5 = Digest::MD5.file(path).digest
-      record.async.update_file(dir, rel_path, data.merge(md5: md5))
+      record.update_file(rel_path, data.merge(md5: md5))
       :modified if record_data[:md5] && md5 != record_data[:md5]
     rescue SystemCallError
-      record.async.unset_path(dir, rel_path)
+      record.unset_path(rel_path)
       :removed
     rescue
-      Celluloid::Logger.debug "lstat failed for: #{rel_path} (#{$ERROR_INFO})"
+      Listen::Logger.debug "lstat failed for: #{rel_path} (#{$ERROR_INFO})"
       raise
     end
 
